import * as React from 'react';
import {Box, TableCell, TableRow} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import {RxModuleComponentModel, RxModuleComponentStore} from "../../../stores/RxModuleComponentStore";
import {useSnackbar} from "notistack";
import {errToString} from "@rx-suite/data";

type Props = {
    model: RxModuleComponentModel
}

export const IconTableRow: React.FunctionComponent<Props> = ({model}) => {
    const {enqueueSnackbar} = useSnackbar();

    const updateIcon = React.useCallback(async () => {
        try {
            enqueueSnackbar(t`Updating icon...`, {variant: "info"});
            await RxModuleComponentStore.transportLayer.fetch(`/${model.getId()}/update_icon`, {method: "POST"});
            enqueueSnackbar(t`Icon updated`, {variant: "success"});
        } catch (e) {
            enqueueSnackbar(t`Icon update failed:` + errToString(e), {variant: "error"});
        }
    }, [enqueueSnackbar, model])

    if (!model.usesIcon) {
        return null
    }

    return (
        <>
            <TableRow>
                <TableCell>{t`Icon`}</TableCell>
                <TableCell>
                    <Box display={"flex"}>
                        <img src={model.icon_url as string} alt={model.module_name as string} width={50}/>
                        <ButtonField text={t`Update Icon`} variant={"outlined"} onClick={updateIcon}/>
                    </Box>
                </TableCell>
            </TableRow>
        </>
    )
}