import * as React from "react";
import {observer} from "mobx-react-lite";
import {SystemSettingModel} from "../../stores/SystemSettingStore";
import {Divider, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {TabPanel, TabPanelProps} from "../component_permissions/TabPanel";
import {makeStyles} from "@material-ui/core/styles";
import {DateTimeFormatSettingsSection} from "./DateTimeFormatSettingsSection";
import {CustomerLogoSettingsSection} from "./CustomerLogoSettingsSection";
import {ModelSelect} from "@rx-suite/ui";

export type DisplaySettingsTabProps = {
    model: SystemSettingModel;
} & TabPanelProps;

const useStyles = makeStyles((theme) => ({
    section: {
        marginTop: theme.spacing(1)
    }
}));

export const DisplaySettingsTab: React.FunctionComponent<DisplaySettingsTabProps> = observer(({
                                                                                                  model,
                                                                                                  value,
                                                                                                  index
                                                                                              }) => {
    const classes = useStyles();

    return (
        <TabPanel value={value} index={index}>
            <DateTimeFormatSettingsSection/>
            <Divider className={classes.section}/>
            <CustomerLogoSettingsSection model={model}/>
            <Divider className={classes.section}/>
            <Typography variant={"h5"}><Trans>Other Display Options</Trans></Typography>
            <ModelSelect name={"lens_tray_orientation"} options={[
                {label: t`L/R`, value: 0},
                {label: t`R/L`, value: 1}
            ]}
                         hint={{
                             title: t`Lens Tray Orientation`,
                             text: t`Changes which eye is shown first in displays that show lens information.`
                         }}/>
        </TabPanel>
    )
})