import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {FormProps, LinkButton, ModelInput, ModelProvider, PaddedPaper, ReadonlyProvider} from "@rx-suite/ui";
import {Grid, LinearProgress, Tab, Tabs} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {RxModuleComponentStore} from "../../stores/RxModuleComponentStore";
import {Permission, RoleModel} from "../../stores/RoleStore";
import {RoleFormButton} from "../../components/roles/RoleFormButton";
import {RoleFormMembersTab} from "../../components/roles/RoleFormMembersTab";
import {RoleFormPermissionsTab} from "../../components/roles/RoleFormPermissionsTab";
import {ComponentPermissionStore} from "../../stores/ComponentPermissionStore";
import {RolePermissionStore} from "../../stores/RolePermissionStore";
import {MenuOpen} from "@material-ui/icons";

type RolesFormProps = {
    model: RoleModel
} & Omit<FormProps, 'model'>

export const RolesForm: React.FunctionComponent<RolesFormProps> = observer(({model, readOnly}) => {
    const permissions = (model.permissions || []) as Permission[];
    const modelId = model.getId();

    const [tab, setTab] = React.useState(0);
    const handleTabChange = React.useCallback((_, value) => {
        setTab(value);
    }, [setTab]);

    React.useEffect(() => {
        ComponentPermissionStore.getAll();
    }, []);

    React.useEffect(() => {
        RolePermissionStore.setFetchParams({
            page: 0,
            limit: 999999,
            sorted: [],
            filtered: [{id: 'role_id', value: model.getId()}]
        }, true);
    }, [model, modelId]);

    if ((RxModuleComponentStore.isLoading && permissions.length === 0) || RolePermissionStore.isLoading) {
        return <LinearProgress color={'secondary'}/>;
    }

    return (
        <ModelProvider value={model}>
            <ReadonlyProvider value={!!readOnly}>
                <Grid container spacing={4}>
                    <Grid item xs={12}>
                        <PaddedPaper>
                            <LinkButton to={model.listLink as string} color={"primary"} noGutter><MenuOpen/> {t`List`}
                            </LinkButton>
                            <Typography variant={'h4'}>{t`Role Information`}</Typography>
                            <ModelInput name={"name"}/>
                        </PaddedPaper>
                    </Grid>
                    <Grid item xs={12}>
                        <PaddedPaper>
                            <Tabs value={tab} onChange={handleTabChange}>
                                <Tab key={0} label={t`Permissions`}/>
                                <Tab key={1} label={t`Members`}/>
                            </Tabs>
                            <RoleFormPermissionsTab value={tab} index={0}/>
                            <RoleFormMembersTab value={tab} index={1}/>
                            <RoleFormButton/>
                        </PaddedPaper>
                    </Grid>
                </Grid>
            </ReadonlyProvider>
        </ModelProvider>
    )
});