import * as React from "react";
import {FormProps, ModelForm, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {LinearProgress, Tab, Tabs,} from "@material-ui/core";
import {t} from "@lingui/macro";
import {DisplaySettingsTab} from "../../components/system_settings/DisplaySettingsTab";
import {SystemSettingModel, SystemSettingStore} from "../../stores/SystemSettingStore";
import {MaintenanceActionsTab} from "../../components/system_settings/MaintenanceActionsTab";

export const SystemSettingForm: React.FunctionComponent<FormProps> = observer(() => {
    const [currentTab, setCurrentTab] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setCurrentTab(newValue);
    };

    const model = SystemSettingStore.selectedModel as SystemSettingModel;

    console.log(SystemSettingStore.selectedModel)

    if (!model) {
        return <LinearProgress color={'secondary'}/>;
    }

    return (
        <PaddedPaper>
            <ModelForm model={model} suppressWrapper suppressMakeCopy suppressImportExport>
                <Tabs value={currentTab} onChange={handleChange} indicatorColor="primary" textColor="primary"
                      variant="scrollable">
                    <Tab label={t`Display Settings`} key={0} />
                    <Tab label={t`Maintenance Actions`} key={1} />
                </Tabs>
                <DisplaySettingsTab model={model} index={0} value={currentTab}/>
                <MaintenanceActionsTab index={1} value={currentTab} />
            </ModelForm>
        </PaddedPaper>
    )
})