Rails.application.routes.draw do
  mount RxModule::Engine => "/api/rx_module"

  scope :api do
    post "delegation" => "delegation#create"

    get "calendar_config" => "calendar_configs#show"
    patch "calendar_config/:id" => "calendar_configs#update"

    get "/packages" => "packages#packages"
    get "/packages/:id" => "packages#package"
    post "/packages" => "packages#install"
    patch "/packages/:id" => "packages#install"
    resources :components do
      resources :component_permissions
      post :update_icon
      get :icon
      resource :logger_config, only: [:show, :update], controller: "components/logger_config"

      member do
        get "endpoint"
        get "email_enabled"
        post "send_email"
        post "startup"
        get "update", action: :upgrade, as: :upgrade
        put "stop"
        put "restart"
      end
    end

    resources :emails
    post "/emails/test" => "emails#send_test_email"

    get "/users/picker" => "users#user_pick"
    post "/users/routine_token" => "users#routine_token"
    post "/users/send_password_email" => "users#send_password_email"
    post "/users/:id/password" => "users#set_password"
    post "/users/:id/get_password_link" => "users#get_password_link"
    post "/users/login" => "users#login"
    post "/users/logout" => "users#logout"

    resources :users do
      resource :role do
        resources :role_permissions, shallow: true
      end
      resources :o_auths do
        get :refresh
        post :activate
      end
    end
    post "/o_auths/:id/activate" => "o_auths#activate", :as => :o_auth_activate
    delete "/o_auths/:id" => "o_auths#destroy", :as => :o_auth_delete

    get "/oauth2/rxuniverse" => "oauth2#rxuniverse"
    get "/oauth2/success", to: redirect("OAuthSuccess.html")

    get "/system_settings/get_system_settings" => "system_settings#get_system_settings"
    get "/system_settings" => "system_settings#show"
    get "/system_settings/customer_logo" => "system_settings#customer_logo"
    get "/system_settings/brand_logo" => "system_settings#brand_logo"
    post "/system_settings" => "system_settings#update"

    post "/components/startup" => "components#startup"
    post "/components/rxuniverse_api_startup" => "components#rxuniverse_api_startup"
    post "/components/register_api_component" => "components#register_api_component"

    post "/roles/create_with_rules" => "roles#create_with_rules"
    post "/roles/update_with_rules" => "roles#update_with_rules"

    get "/licence" => "licence_infos#licence"
    get "/licence_info" => "licence_infos#index"
    get "/licence_info/:id" => "licence_infos#show"
    post "/licence_info" => "licence_infos#update"
    post "/licence_info/:id" => "licence_infos#update"
    patch "/licence_info/:id" => "licence_infos#update"

    resources :roles do
      resources :role_permissions
    end

    resources :role_permissions
    resources :component_permissions

    get "/shifts/current" => "shifts#current_shifts"
    get "/shifts/instances" => "shifts#instances"
    post "/shifts/preview" => "shifts#preview"
    get "/shifts/active_ranges_between" => "shifts#active_ranges_between"
    resources :shifts

    post "maintenance/invalidate_user_cache" => "maintenance/invalidate_user_cache#create"
    post "maintenance/invalidate_endpoint_cache" => "maintenance/invalidate_endpoint_cache#create"
  end

  root "/", controller: :index, action: :show
  get "*path" => "index#show", :constraints => lambda { |req|
    req.path.exclude? "rails/active_storage"
  }
end
